@@ -12,7 +12,7 @@ string_ends_with <- function(pattern, x) {
 
 #' @keywords internal
 string_one_of <- function(pattern, x) {
-  m <- unlist(lapply(pattern, function(.x) grep(.x, x, fixed = TRUE, useBytes = TRUE)))
+  m <- unlist(lapply(pattern, grep, x = x, fixed = TRUE, useBytes = TRUE))
   x[m]
 }
 
